gramex.apps package
===================

Subpackages
-----------

.. toctree::

   gramex.apps.languagetool
   gramex.apps.logviewer
   gramex.apps.nlg
   gramex.apps.ui

Module contents
---------------

.. automodule:: gramex.apps
   :members:
   :undoc-members:
   :show-inheritance:
